
From: Jeff Dike <jdike@addtoit.com>

This patch moves code that is in both switch_to_tt and switch_to_skas to the
top level _switch_to function, keeping us from duplicating code.  It is
required for the stack trace patch to work properly.

Signed-off-by: Allan Graves <allan.graves@gmail.com>
Signed-off-by: Jeff Dike <jdike@addtoit.com>
Cc: Paolo Giarrusso <blaisorblade@yahoo.it>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/um/kernel/process_kern.c                |   12 ++++++++++--
 arch/um/kernel/skas/include/mode_kern-skas.h |    2 +-
 arch/um/kernel/skas/process_kern.c           |    7 +------
 arch/um/kernel/tt/include/mode_kern-tt.h     |    2 +-
 arch/um/kernel/tt/process_kern.c             |    7 +------
 5 files changed, 14 insertions(+), 16 deletions(-)

diff -puN arch/um/kernel/process_kern.c~uml-_switch_to-code-consolidation arch/um/kernel/process_kern.c
--- devel/arch/um/kernel/process_kern.c~uml-_switch_to-code-consolidation	2005-09-14 22:24:58.000000000 -0700
+++ devel-akpm/arch/um/kernel/process_kern.c	2005-09-14 22:24:58.000000000 -0700
@@ -113,8 +113,16 @@ void set_current(void *t)
 
 void *_switch_to(void *prev, void *next, void *last)
 {
-	return(CHOOSE_MODE(switch_to_tt(prev, next), 
-			   switch_to_skas(prev, next)));
+        struct task_struct *from = prev;
+        struct task_struct *to= next;
+
+        to->thread.prev_sched = from;
+        set_current(to);
+
+	CHOOSE_MODE_PROC(switch_to_tt, switch_to_skas, prev, next);
+
+        return(current->thread.prev_sched);
+
 }
 
 void interrupt_end(void)
diff -puN arch/um/kernel/skas/include/mode_kern-skas.h~uml-_switch_to-code-consolidation arch/um/kernel/skas/include/mode_kern-skas.h
--- devel/arch/um/kernel/skas/include/mode_kern-skas.h~uml-_switch_to-code-consolidation	2005-09-14 22:24:58.000000000 -0700
+++ devel-akpm/arch/um/kernel/skas/include/mode_kern-skas.h	2005-09-14 22:24:58.000000000 -0700
@@ -11,7 +11,7 @@
 #include "asm/ptrace.h"
 
 extern void flush_thread_skas(void);
-extern void *switch_to_skas(void *prev, void *next);
+extern void switch_to_skas(void *prev, void *next);
 extern void start_thread_skas(struct pt_regs *regs, unsigned long eip,
 			      unsigned long esp);
 extern int copy_thread_skas(int nr, unsigned long clone_flags,
diff -puN arch/um/kernel/skas/process_kern.c~uml-_switch_to-code-consolidation arch/um/kernel/skas/process_kern.c
--- devel/arch/um/kernel/skas/process_kern.c~uml-_switch_to-code-consolidation	2005-09-14 22:24:58.000000000 -0700
+++ devel-akpm/arch/um/kernel/skas/process_kern.c	2005-09-14 22:24:58.000000000 -0700
@@ -24,7 +24,7 @@
 #include "proc_mm.h"
 #include "registers.h"
 
-void *switch_to_skas(void *prev, void *next)
+void switch_to_skas(void *prev, void *next)
 {
 	struct task_struct *from, *to;
 
@@ -35,16 +35,11 @@ void *switch_to_skas(void *prev, void *n
 	if(current->pid == 0)
 		switch_timers(0);
 
-	to->thread.prev_sched = from;
-	set_current(to);
-
 	switch_threads(&from->thread.mode.skas.switch_buf, 
 		       to->thread.mode.skas.switch_buf);
 
 	if(current->pid == 0)
 		switch_timers(1);
-
-	return(current->thread.prev_sched);
 }
 
 extern void schedule_tail(struct task_struct *prev);
diff -puN arch/um/kernel/tt/include/mode_kern-tt.h~uml-_switch_to-code-consolidation arch/um/kernel/tt/include/mode_kern-tt.h
--- devel/arch/um/kernel/tt/include/mode_kern-tt.h~uml-_switch_to-code-consolidation	2005-09-14 22:24:58.000000000 -0700
+++ devel-akpm/arch/um/kernel/tt/include/mode_kern-tt.h	2005-09-14 22:24:58.000000000 -0700
@@ -11,7 +11,7 @@
 #include "asm/ptrace.h"
 #include "asm/uaccess.h"
 
-extern void *switch_to_tt(void *prev, void *next);
+extern void switch_to_tt(void *prev, void *next);
 extern void flush_thread_tt(void);
 extern void start_thread_tt(struct pt_regs *regs, unsigned long eip,
 			   unsigned long esp);
diff -puN arch/um/kernel/tt/process_kern.c~uml-_switch_to-code-consolidation arch/um/kernel/tt/process_kern.c
--- devel/arch/um/kernel/tt/process_kern.c~uml-_switch_to-code-consolidation	2005-09-14 22:24:58.000000000 -0700
+++ devel-akpm/arch/um/kernel/tt/process_kern.c	2005-09-14 22:24:58.000000000 -0700
@@ -26,7 +26,7 @@
 #include "init.h"
 #include "tt.h"
 
-void *switch_to_tt(void *prev, void *next, void *last)
+int switch_to_tt(void *prev, void *next, void *last)
 {
 	struct task_struct *from, *to, *prev_sched;
 	unsigned long flags;
@@ -36,8 +36,6 @@ void *switch_to_tt(void *prev, void *nex
 	from = prev;
 	to = next;
 
-	to->thread.prev_sched = from;
-
 	cpu = from->thread_info->cpu;
 	if(cpu == 0)
 		forward_interrupts(to->thread.mode.tt.extern_pid);
@@ -53,7 +51,6 @@ void *switch_to_tt(void *prev, void *nex
 	forward_pending_sigio(to->thread.mode.tt.extern_pid);
 
 	c = 0;
-	set_current(to);
 
 	err = os_write_file(to->thread.mode.tt.switch_pipe[1], &c, sizeof(c));
 	if(err != sizeof(c))
@@ -85,8 +82,6 @@ void *switch_to_tt(void *prev, void *nex
 
 	flush_tlb_all();
 	local_irq_restore(flags);
-
-	return(current->thread.prev_sched);
 }
 
 void release_thread_tt(struct task_struct *task)
_
